import React, { useEffect, useState } from "react";
import { useSelector, useDispatch } from "react-redux"; // Import useDispatch
import CreateActivityButton from '../../components/modal/createActivityButton.jsx';
import Table from '../../components/table/index.jsx';
import Loading from "../../components/loading Component/Loading.jsx";
import { styles } from './styles.js';
import { convertToString } from "../../utils/commonFunctions.js";
import axiosApi from '../../api/axiosConfig.js'
import ConfirmPopup from "../../components/confirmationPopup/index.jsx";
import { toast } from 'react-toastify';

const ActivityList = () => {
  const [activitiesList, setActivitiesList] = useState([]);
  const { loading } = useSelector((state) => state.reportees);
  const [deleteId, setDeleteId] = useState(null);
  const [deleteActivity, setDeleteActivity] = useState(null)
  const dispatch = useDispatch(); // Initialize useDispatch

const fetchActivityData = async () => {
  try {
    const response = await axiosApi.get(`/activities`);
    setActivitiesList(response.data)
    
  } catch (error) {
    // console.error('Error fetching data:', error);
    throw error; // Rethrow the error for handling by the caller if needed
  }
};

  useEffect(() => {
    fetchActivityData();
  }, []);

  const handleDelete = async (_id) => {
    try {
        //console.log("Deleting activity with id:", _id);
        await axiosApi.put(`/deleteMasterActivity`, { ObjectId: _id });
        toast.success('Activity deleted successfully.')
        fetchActivityData();
    } catch (error) {
        // console.error("Error deleting activity:", _id);
        // console.error("Error:", error);
    } finally {
      setDeleteId(null);
    }
};

  const headers = [
    { title: "Activity Type", id: "atype" },
    { title: "Activity Name", id: "aName" },
    { title: "Appreciate", id: "appreciate", render: (value) => convertToString(value) },
    { title: "Depreciate", id: "depreciate", render: (value) => convertToString(value) },
    {
      title: "Actions",
      id: "_id",
      render: (id, item) => (
        <button
          className="bg-red-400 text-white rounded-md px-1 py-1 flex items-center justify-center w-[40px]"
          onClick={() => {setDeleteId(id); setDeleteActivity(item.aName)}}
        >
          X
        </button>
      )
    },
  ];

  if (loading) return <Loading />;

  return (
    <div>
      <div className={styles.createActivityContainer}>
        <div className={styles.textBlueHeading}>
          ACTIVITY LIST
        </div>
        <div className="flex" style={{ justifyContent: 'flex-end', marginBottom: "10px" }}>
          <CreateActivityButton handleRefresh={() => fetchActivityData()} />
        </div>
        <Table headers={headers} loading={loading} data={activitiesList} />
      </div>
      <ConfirmPopup 
        open={deleteId ? true : false}
        header='Delete Activity'
        content={`Are you sure want to delete ${deleteActivity} activity.`}
        handleCancel={() => setDeleteId(null)}
        handleConfirm={() => handleDelete(deleteId)}
      />
    </div>
  );
};

export default ActivityList;
